JsonAnimatedAlignBuilderModel class

Creates a widget that positions its child by an alignment that animates implicitly.

Inheritance

Constructors

JsonAnimatedAlignBuilderModel(Map<String, dynamic> args, {required AlignmentGeometry alignment, Curve curve = Curves.linear, required Duration duration, double? heightFactor, void onEnd()?, double? widthFactor, JsonWidgetData? child})
const

Properties

alignment → AlignmentGeometry
How to align the child.
final
args → Map<String, dynamic>
finalinherited
child → JsonWidgetData?
The widget below this widget in the tree.
final
curve → Curve
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
heightFactor → double?
If non-null, sets its height to the child's height multiplied by this factor.
final
onEnd → void Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widthFactor → double?
If non-null, sets its width to the child's width multiplied by this factor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedAlignBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedAlignBuilderModel?