JsonAnimatedContainerBuilderModel class

Creates a container that animates its parameters implicitly.

Inheritance

Constructors

JsonAnimatedContainerBuilderModel(Map<String, dynamic> args, {AlignmentGeometry? alignment, Clip clipBehavior = Clip.none, Color? color, BoxConstraints? constraints, Curve curve = Curves.linear, required dynamic decoration, required Duration duration, required dynamic foregroundDecoration, double? height, EdgeInsetsGeometry? margin, void onEnd()?, EdgeInsetsGeometry? padding, Matrix4? transform, AlignmentGeometry? transformAlignment, double? width, JsonWidgetData? child})
const

Properties

alignment → AlignmentGeometry?
Align the child within the container.
final
args → Map<String, dynamic>
finalinherited
child → JsonWidgetData?
The child contained by the container.
final
clipBehavior → Clip
The clip behavior when AnimatedContainer.decoration is not null.
final
color → Color?
final
constraints → BoxConstraints?
Additional constraints to apply to the child.
final
curve → Curve
final
decoration → dynamic
The decoration to paint behind the child.
final
duration → Duration
final
foregroundDecoration → dynamic
The decoration to paint in front of the child.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
margin → EdgeInsetsGeometry?
Empty space to surround the decoration and child.
final
onEnd → void Function()?
final
padding → EdgeInsetsGeometry?
Empty space to inscribe inside the decoration. The child, if any, is placed inside this padding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform → Matrix4?
The transformation matrix to apply before painting the container.
final
transformAlignment → AlignmentGeometry?
The alignment of the origin, relative to the size of the container, if transform is specified.
final
width → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedContainerBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedContainerBuilderModel?