JsonAnimatedDefaultTextStyleBuilderModel class

Creates a widget that animates the default text style implicitly.

Inheritance

Constructors

JsonAnimatedDefaultTextStyleBuilderModel(Map<String, dynamic> args, {Curve curve = Curves.linear, required Duration duration, int? maxLines, void onEnd()?, TextOverflow overflow = TextOverflow.clip, bool softWrap = true, required TextStyle style, TextAlign? textAlign, TextHeightBehavior? textHeightBehavior, TextWidthBasis textWidthBasis = TextWidthBasis.parent, required JsonWidgetData child})
const

Properties

args → Map<String, dynamic>
finalinherited
child → JsonWidgetData
The widget below this widget in the tree.
final
curve → Curve
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
maxLines → int?
An optional maximum number of lines for the text to span, wrapping if necessary.
final
onEnd → void Function()?
final
overflow → TextOverflow
How visual overflow should be handled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softWrap → bool
Whether the text should break at soft line breaks.
final
style → TextStyle
The target text style.
final
textAlign → TextAlign?
How the text should be aligned horizontally.
final
textHeightBehavior → TextHeightBehavior?
Defines how to apply TextStyle.height over and under text.
final
textWidthBasis → TextWidthBasis
The strategy to use when calculating the width of the Text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedDefaultTextStyleBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedDefaultTextStyleBuilderModel?