JsonAnimatedPhysicalModelBuilderModel class

Creates a widget that animates the properties of a PhysicalModel.

The elevation must be non-negative.

Animating color is optional and is controlled by the animateColor flag.

Animating shadowColor is optional and is controlled by the animateShadowColor flag.

Inheritance

Constructors

JsonAnimatedPhysicalModelBuilderModel(Map<String, dynamic> args, {bool animateColor = true, bool animateShadowColor = true, BorderRadius? borderRadius, Clip clipBehavior = Clip.none, required Color color, Curve curve = Curves.linear, required Duration duration, double elevation = 0.0, void onEnd()?, required Color shadowColor, BoxShape shape = BoxShape.rectangle, required JsonWidgetData child})
const

Properties

animateColor → bool
Whether the color should be animated.
final
animateShadowColor → bool
Whether the shadow color should be animated.
final
args → Map<String, dynamic>
finalinherited
borderRadius → BorderRadius?
The target border radius of the rounded corners for a rectangle shape.
final
child → JsonWidgetData
The widget below this widget in the tree.
final
clipBehavior → Clip
The content will be clipped (or not) according to this option.
final
color → Color
The target background color.
final
curve → Curve
final
duration → Duration
final
elevation → double
The target z-coordinate relative to the parent at which to place this physical object.
final
hashCode → int
The hash code for this object.
no setterinherited
onEnd → void Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color
The target shadow color.
final
shape → BoxShape
The type of shape.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedPhysicalModelBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonAnimatedPhysicalModelBuilderModel?