JsonGridViewBuilderModel class

Inheritance

Constructors

JsonGridViewBuilderModel(Map<String, dynamic> args, {bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, Widget childBuilder(BuildContext, Widget)?, Clip clipBehavior = Clip.hardEdge, ScrollController? controller, DragStartBehavior dragStartBehavior = DragStartBehavior.start, int? findChildIndexCallback(Key)?, required dynamic gridDelegate, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, EdgeInsets? padding, ScrollPhysics? physics, required bool primary, String? restorationId, bool reverse = false, Axis scrollDirection = Axis.vertical, bool shrinkWrap = false, List<JsonWidgetData>? children})
const

Properties

addAutomaticKeepAlives → bool
final
addRepaintBoundaries → bool
final
addSemanticIndexes → bool
final
args → Map<String, dynamic>
finalinherited
cacheExtent → double?
final
childBuilder → Widget Function(BuildContext, Widget)?
final
children → List<JsonWidgetData>?
final
clipBehavior → Clip
final
controller → ScrollController?
final
dragStartBehavior → DragStartBehavior
final
findChildIndexCallback → int? Function(Key)?
final
gridDelegate → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
final
padding → EdgeInsets?
final
physics → ScrollPhysics?
final
primary → bool
final
restorationId → String?
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
final
shrinkWrap → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonGridViewBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonGridViewBuilderModel?