JsonInkWellBuilderModel class

Creates an ink well.

Must have an ancestor Material widget in which to cause ink reactions.

Inheritance

Constructors

JsonInkWellBuilderModel(Map<String, dynamic> args, {bool autofocus = false, BorderRadius? borderRadius, bool canRequestFocus = true, ShapeBorder? customBorder, bool enableFeedback = true, bool excludeFromSemantics = false, Color? focusColor, FocusNode? focusNode, Color? highlightColor, Color? hoverColor, Duration? hoverDuration, MouseCursor? mouseCursor, void onDoubleTap()?, void onFocusChange(bool)?, void onHighlightChanged(bool)?, void onHover(bool)?, void onLongPress()?, void onLongPressUp()?, void onSecondaryTap()?, void onSecondaryTapCancel()?, void onSecondaryTapDown(TapDownDetails)?, void onSecondaryTapUp(TapUpDetails)?, void onTap()?, void onTapCancel()?, void onTapDown(TapDownDetails)?, void onTapUp(TapUpDetails)?, WidgetStateProperty<Color?>? overlayColor, double? radius, Color? splashColor, InteractiveInkFeatureFactory? splashFactory, WidgetStatesController? statesController, JsonWidgetData? child})
const

Properties

args → Map<String, dynamic>
finalinherited
autofocus → bool
final
borderRadius → BorderRadius?
final
canRequestFocus → bool
final
child → JsonWidgetData?
final
customBorder → ShapeBorder?
final
enableFeedback → bool
final
excludeFromSemantics → bool
final
focusColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
final
hoverColor → Color?
final
hoverDuration → Duration?
final
mouseCursor → MouseCursor?
final
onDoubleTap → void Function()?
final
onFocusChange → void Function(bool)?
final
onHighlightChanged → void Function(bool)?
final
onHover → void Function(bool)?
final
onLongPress → void Function()?
final
onLongPressUp → void Function()?
final
onSecondaryTap → void Function()?
final
onSecondaryTapCancel → void Function()?
final
onSecondaryTapDown → void Function(TapDownDetails)?
final
onSecondaryTapUp → void Function(TapUpDetails)?
final
onTap → void Function()?
final
onTapCancel → void Function()?
final
onTapDown → void Function(TapDownDetails)?
final
onTapUp → void Function(TapUpDetails)?
final
overlayColor → WidgetStateProperty<Color?>?
final
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splashColor → Color?
final
splashFactory → InteractiveInkFeatureFactory?
final
statesController → WidgetStatesController?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonInkWellBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonInkWellBuilderModel?