JsonListTileTheme class

Inheritance

Constructors

JsonListTileTheme({Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry, EdgeInsetsGeometry? contentPadding, ListTileControlAffinity? controlAffinity, ListTileThemeData? data, bool? dense, bool? enableFeedback, double? horizontalTitleGap, Color? iconColor, double? minLeadingWidth, double? minVerticalPadding, WidgetStateProperty<MouseCursor?>? mouseCursor, Color? selectedColor, Color? selectedTileColor, ShapeBorder? shape, ListTileStyle? style, Color? textColor, Color? tileColor, required JsonWidgetData child})

Properties

child → JsonWidgetData
final
contentPadding → EdgeInsetsGeometry?
final
controlAffinity → ListTileControlAffinity?
final
data → ListTileThemeData?
final
dense → bool?
final
enableFeedback → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalTitleGap → double?
final
iconColor → Color?
final
jsonWidgetArgs → dynamic
finalinherited
jsonWidgetBuilder → JsonWidgetBuilder Function()
finalinherited
jsonWidgetId → String
finalinherited
jsonWidgetListenVariables → Set<String>
finalinherited
jsonWidgetRegistry → JsonWidgetRegistry
finalinherited
jsonWidgetType → String
finalinherited
minLeadingWidth → double?
final
minVerticalPadding → double?
final
mouseCursor → WidgetStateProperty<MouseCursor?>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
final
selectedTileColor → Color?
final
shape → ShapeBorder?
final
style → ListTileStyle?
final
textColor → Color?
final
tileColor → Color?
final

Methods

build({ChildWidgetBuilder? childBuilder, required BuildContext context, JsonWidgetRegistry? registry}) → Widget
Convenience method that can build the widget this data object represents. This is the equilivant of calling: builder.build and passing this in as the data parameter.
inherited
copyWith({dynamic jsonWidgetArgs, JsonWidgetBuilder? jsonWidgetBuilder, Set<String>? jsonWidgetListenVariables, String? jsonWidgetId, JsonWidgetRegistry? jsonWidgetRegistry, String? jsonWidgetType}) → JsonWidgetData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
inherited
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited