JsonListView class

Inheritance

Constructors

JsonListView({Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, Clip clipBehavior = Clip.hardEdge, ScrollController? controller, DragStartBehavior dragStartBehavior = DragStartBehavior.start, int? findChildIndexCallback(Key)?, double? itemExtent, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, EdgeInsets? padding, ScrollPhysics? physics, bool? primary, JsonWidgetData? prototypeItem, String? restorationId, bool reverse = false, Axis scrollDirection = Axis.vertical, bool shrinkWrap = false, List<JsonWidgetData>? children})

Properties

addAutomaticKeepAlives → bool
final
addRepaintBoundaries → bool
final
addSemanticIndexes → bool
final
cacheExtent → double?
final
children → List<JsonWidgetData>?
final
clipBehavior → Clip
final
controller → ScrollController?
final
dragStartBehavior → DragStartBehavior
final
findChildIndexCallback → int? Function(Key)?
final
hashCode → int
The hash code for this object.
no setterinherited
hasProvidedId → bool
finalinherited
itemExtent → double?
final
jsonWidgetArgs → dynamic
finalinherited
jsonWidgetBuilder → JsonWidgetBuilder Function()
finalinherited
jsonWidgetId → String
finalinherited
jsonWidgetListenVariables → Set<String>
finalinherited
jsonWidgetRegistry → JsonWidgetRegistry
finalinherited
jsonWidgetType → String
finalinherited
keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
final
padding → EdgeInsets?
final
physics → ScrollPhysics?
final
primary → bool?
final
prototypeItem → JsonWidgetData?
final
restorationId → String?
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
final
shrinkWrap → bool
final

Methods

build({ChildWidgetBuilder? childBuilder, required BuildContext context, JsonWidgetRegistry? registry}) → Widget
Convenience method that can build the widget this data object represents. This is the equilivant of calling: builder.build and passing this in as the data parameter.
inherited
copyWith({dynamic jsonWidgetArgs, JsonWidgetBuilder? jsonWidgetBuilder, Set<String>? jsonWidgetListenVariables, String? jsonWidgetId, JsonWidgetRegistry? jsonWidgetRegistry, String? jsonWidgetType}) → JsonWidgetData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
inherited
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited