JsonMemoryImage class

Inheritance

Constructors

JsonMemoryImage({Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry, Alignment alignment = Alignment.center, int? cacheHeight, int? cacheWidth, Rect? centerSlice, Color? color, BlendMode? colorBlendMode, Widget errorBuilder(BuildContext, Object, StackTrace?)?, bool excludeFromSemantics = false, FilterQuality filterQuality = FilterQuality.low, BoxFit? fit, Widget frameBuilder(BuildContext, Widget, int?, bool)?, bool gaplessPlayback = false, double? height, required dynamic image, bool isAntiAlias = false, bool matchTextDirection = false, double? opacity, ImageRepeat repeat = ImageRepeat.noRepeat, double scale = 1.0, String? semanticLabel, double? width})

Properties

alignment → Alignment
final
cacheHeight → int?
final
cacheWidth → int?
final
centerSlice → Rect?
final
color → Color?
final
colorBlendMode → BlendMode?
final
errorBuilder → Widget Function(BuildContext, Object, StackTrace?)?
final
excludeFromSemantics → bool
final
filterQuality → FilterQuality
final
fit → BoxFit?
final
frameBuilder → Widget Function(BuildContext, Widget, int?, bool)?
final
gaplessPlayback → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
image → dynamic
final
isAntiAlias → bool
final
jsonWidgetArgs → dynamic
finalinherited
jsonWidgetBuilder → JsonWidgetBuilder Function()
finalinherited
jsonWidgetId → String
finalinherited
jsonWidgetListenVariables → Set<String>
finalinherited
jsonWidgetRegistry → JsonWidgetRegistry
finalinherited
jsonWidgetType → String
finalinherited
matchTextDirection → bool
final
opacity → double?
final
repeat → ImageRepeat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
semanticLabel → String?
final
width → double?
final

Methods

build({ChildWidgetBuilder? childBuilder, required BuildContext context, JsonWidgetRegistry? registry}) → Widget
Convenience method that can build the widget this data object represents. This is the equilivant of calling: builder.build and passing this in as the data parameter.
inherited
copyWith({dynamic jsonWidgetArgs, JsonWidgetBuilder? jsonWidgetBuilder, Set<String>? jsonWidgetListenVariables, String? jsonWidgetId, JsonWidgetRegistry? jsonWidgetRegistry, String? jsonWidgetType}) → JsonWidgetData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
inherited
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited