JsonMergeSemantics class

Inheritance

Constructors

JsonMergeSemantics({Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry, JsonWidgetData? child})

Properties

child → JsonWidgetData?
final
hashCode → int
The hash code for this object.
no setterinherited
hasProvidedId → bool
finalinherited
jsonWidgetArgs → dynamic
finalinherited
jsonWidgetBuilder → JsonWidgetBuilder Function()
finalinherited
jsonWidgetId → String
finalinherited
jsonWidgetListenVariables → Set<String>
finalinherited
jsonWidgetRegistry → JsonWidgetRegistry
finalinherited
jsonWidgetType → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({ChildWidgetBuilder? childBuilder, required BuildContext context, JsonWidgetRegistry? registry}) → Widget
Convenience method that can build the widget this data object represents. This is the equilivant of calling: builder.build and passing this in as the data parameter.
inherited
copyWith({dynamic jsonWidgetArgs, JsonWidgetBuilder? jsonWidgetBuilder, Set<String>? jsonWidgetListenVariables, String? jsonWidgetId, JsonWidgetRegistry? jsonWidgetRegistry, String? jsonWidgetType}) → JsonWidgetData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
inherited
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited