JsonOutlinedButtonBuilderModel class

Create an OutlinedButton.

Inheritance

Constructors

JsonOutlinedButtonBuilderModel(Map<String, dynamic> args, {bool autofocus = false, Clip? clipBehavior, FocusNode? focusNode, void onFocusChange(bool)?, void onHover(bool)?, void onLongPress()?, required void onPressed()?, WidgetStatesController? statesController, ButtonStyle? style, required JsonWidgetData? child})
const

Properties

args → Map<String, dynamic>
finalinherited
autofocus → bool
final
child → JsonWidgetData?
final
clipBehavior → Clip?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
onFocusChange → void Function(bool)?
final
onHover → void Function(bool)?
final
onLongPress → void Function()?
final
onPressed → void Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statesController → WidgetStatesController?
final
style → ButtonStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonOutlinedButtonBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonOutlinedButtonBuilderModel?