JsonScrollbar class

Inheritance

Constructors

JsonScrollbar({Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry, ScrollController? controller, bool? interactive, bool notificationPredicate(ScrollNotification)?, Radius? radius, ScrollbarOrientation? scrollbarOrientation, double? thickness, bool? thumbVisibility, bool? trackVisibility, required JsonWidgetData child})

Properties

child → JsonWidgetData
The widget below this widget in the tree.
final
controller → ScrollController?
The ScrollController used to implement Scrollbar dragging.
final
hashCode → int
The hash code for this object.
no setterinherited
interactive → bool?
Whether the Scrollbar should be interactive and respond to dragging on the thumb, or tapping in the track area.
final
jsonWidgetArgs → dynamic
finalinherited
jsonWidgetBuilder → JsonWidgetBuilder Function()
finalinherited
jsonWidgetId → String
finalinherited
jsonWidgetListenVariables → Set<String>
finalinherited
jsonWidgetRegistry → JsonWidgetRegistry
finalinherited
jsonWidgetType → String
finalinherited
notificationPredicate → bool Function(ScrollNotification)?
A check that specifies whether a ScrollNotification should be handled by this widget.
final
radius → Radius?
The Radius of the scrollbar thumb's rounded rectangle corners.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollbarOrientation → ScrollbarOrientation?
Dictates the orientation of the scrollbar.
final
thickness → double?
The thickness of the scrollbar in the cross axis of the scrollable.
final
thumbVisibility → bool?
Indicates that the scrollbar thumb should be visible, even when a scroll is not underway.
final
trackVisibility → bool?
Indicates that the scrollbar track should be visible.
final

Methods

build({ChildWidgetBuilder? childBuilder, required BuildContext context, JsonWidgetRegistry? registry}) → Widget
Convenience method that can build the widget this data object represents. This is the equilivant of calling: builder.build and passing this in as the data parameter.
inherited
copyWith({dynamic jsonWidgetArgs, JsonWidgetBuilder? jsonWidgetBuilder, Set<String>? jsonWidgetListenVariables, String? jsonWidgetId, JsonWidgetRegistry? jsonWidgetRegistry, String? jsonWidgetType}) → JsonWidgetData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
inherited
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited