JsonSetWidgetBuilderModel class

Inheritance

Constructors

JsonSetWidgetBuilderModel(Map<String, dynamic> args, {Map? widgets, JsonWidgetData? child})
const

Properties

args → Map<String, dynamic>
finalinherited
child → JsonWidgetData?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgets → Map?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonSetWidgetBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonSetWidgetBuilderModel?