JsonTabBarThemeBuilderModel class

Creates a tab bar theme that can be used with ThemeData.tabBarTheme.

Inheritance

Constructors

JsonTabBarThemeBuilderModel(Map<String, dynamic> args, {TabBarThemeData? data, Color? dividerColor, double? dividerHeight, Decoration? indicator, TabIndicatorAnimation? indicatorAnimation, Color? indicatorColor, TabBarIndicatorSize? indicatorSize, Color? labelColor, EdgeInsetsGeometry? labelPadding, TextStyle? labelStyle, WidgetStateProperty<MouseCursor?>? mouseCursor, WidgetStateProperty<Color?>? overlayColor, InteractiveInkFeatureFactory? splashFactory, TabAlignment? tabAlignment, TextScaler? textScaler, Color? unselectedLabelColor, TextStyle? unselectedLabelStyle, JsonWidgetData? child})
const

Properties

args → Map<String, dynamic>
finalinherited
child → JsonWidgetData?
final
data → TabBarThemeData?
final
dividerColor → Color?
final
dividerHeight → double?
final
hashCode → int
The hash code for this object.
no setterinherited
indicator → Decoration?
final
indicatorAnimation → TabIndicatorAnimation?
final
indicatorColor → Color?
final
indicatorSize → TabBarIndicatorSize?
final
labelColor → Color?
final
labelPadding → EdgeInsetsGeometry?
final
labelStyle → TextStyle?
final
mouseCursor → WidgetStateProperty<MouseCursor?>?
final
overlayColor → WidgetStateProperty<Color?>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splashFactory → InteractiveInkFeatureFactory?
final
tabAlignment → TabAlignment?
final
textScaler → TextScaler?
final
unselectedLabelColor → Color?
final
unselectedLabelStyle → TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonTabBarThemeBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonTabBarThemeBuilderModel?