JsonWidgetData class

Inheritance
Implementers

Constructors

JsonWidgetData({dynamic jsonWidgetArgs, required JsonWidgetBuilder jsonWidgetBuilder(), Set<String>? jsonWidgetListenVariables, String? jsonWidgetId, JsonWidgetRegistry? jsonWidgetRegistry, required String jsonWidgetType})

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonWidgetArgs → dynamic
final
jsonWidgetBuilder → JsonWidgetBuilder Function()
final
jsonWidgetId → String
final
jsonWidgetListenVariables → Set<String>
final
jsonWidgetRegistry → JsonWidgetRegistry
final
jsonWidgetType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({ChildWidgetBuilder? childBuilder, required BuildContext context, JsonWidgetRegistry? registry}) → Widget
Convenience method that can build the widget this data object represents. This is the equilivant of calling: builder.build and passing this in as the data parameter.
copyWith({dynamic jsonWidgetArgs, JsonWidgetBuilder? jsonWidgetBuilder, Set<String>? jsonWidgetListenVariables, String? jsonWidgetId, JsonWidgetRegistry? jsonWidgetRegistry, String? jsonWidgetType}) → JsonWidgetData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {JsonWidgetRegistry? registry}) → JsonWidgetData
Decodes a JSON object into a dynamic widget. The structure is the same for all dynamic widgets with the exception of the args value. The args depends on the specific type.
fromDynamicList(dynamic list, {JsonWidgetRegistry? registry}) → List<JsonWidgetData>
Helper function to create a list of dynamic objects given a builder that can build a single object.
override
maybeFromDynamic(dynamic map, {JsonWidgetRegistry? registry}) → JsonWidgetData?
Decodes a JSON object into a dynamic widget. The structure is the same for all dynamic widgets with the exception of the args value. The args depends on the specific type.
maybeFromDynamicList(dynamic list, {JsonWidgetRegistry? registry}) → List<JsonWidgetData>?
Returns a parsed list from a dynamic Iterable. If the passed in list is null then this will return null.
override