JsonSemanticsBuilderModel class

Creates a semantic annotation.

To create a const instance of Semantics, use the Semantics.fromProperties constructor.

Used by assistive technologies, search engines, and other semantic analysis software to determine the meaning of the application.

See also:

Inheritance

Constructors

JsonSemanticsBuilderModel(Map<String, dynamic> args, {AttributedString? attributedDecreasedValue, AttributedString? attributedHint, AttributedString? attributedIncreasedValue, AttributedString? attributedLabel, AttributedString? attributedValue, bool blockUserActions = false, bool? button, bool? checked, bool container = false, Set<String>? controlsNodes, int? currentValueLength, Map<CustomSemanticsAction, void Function()>? customSemanticsActions, String? decreasedValue, bool? enabled, bool excludeSemantics = false, bool? expanded, bool explicitChildNodes = false, bool? focusable, bool? focused, bool? header, int? headingLevel, bool? hidden, String? hint, String? identifier, bool? image, bool? inMutuallyExclusiveGroup, String? increasedValue, SemanticsInputType? inputType, bool? isRequired, bool? keyboardKey, String? label, bool? link, Uri? linkUrl, bool? liveRegion, Locale? localeForSubtree, int? maxValueLength, bool? mixed, bool? multiline, bool? namesRoute, bool? obscured, void onCollapse()?, void onCopy()?, void onCut()?, void onDecrease()?, void onDidGainAccessibilityFocus()?, void onDidLoseAccessibilityFocus()?, void onDismiss()?, void onExpand()?, void onFocus()?, void onIncrease()?, void onLongPress()?, String? onLongPressHint, void onMoveCursorBackwardByCharacter(bool)?, void onMoveCursorForwardByCharacter(bool)?, void onPaste()?, void onScrollDown()?, void onScrollLeft()?, void onScrollRight()?, void onScrollUp()?, void onSetSelection(TextSelection)?, void onSetText(String)?, void onTap()?, String? onTapHint, bool? readOnly, SemanticsRole? role, bool? scopesRoute, bool? selected, bool? slider, dynamic sortKey = null, SemanticsTag? tagForChildren, TextDirection? textDirection, bool? textField, bool? toggled, String? tooltip, SemanticsValidationResult validationResult = SemanticsValidationResult.none, String? value, JsonWidgetData? child})
const

Properties

args → Map<String, dynamic>
finalinherited
attributedDecreasedValue → AttributedString?
final
attributedHint → AttributedString?
final
attributedIncreasedValue → AttributedString?
final
attributedLabel → AttributedString?
final
attributedValue → AttributedString?
final
blockUserActions → bool
final
button → bool?
final
checked → bool?
final
child → JsonWidgetData?
final
container → bool
final
controlsNodes → Set<String>?
final
currentValueLength → int?
final
customSemanticsActions → Map<CustomSemanticsAction, void Function()>?
final
decreasedValue → String?
final
enabled → bool?
final
excludeSemantics → bool
final
expanded → bool?
final
explicitChildNodes → bool
final
focusable → bool?
final
focused → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
final
headingLevel → int?
final
hidden → bool?
final
hint → String?
final
identifier → String?
final
image → bool?
final
increasedValue → String?
final
inMutuallyExclusiveGroup → bool?
final
inputType → SemanticsInputType?
final
isRequired → bool?
final
keyboardKey → bool?
final
label → String?
final
final
linkUrl → Uri?
final
liveRegion → bool?
final
localeForSubtree → Locale?
final
maxValueLength → int?
final
mixed → bool?
final
multiline → bool?
final
namesRoute → bool?
final
obscured → bool?
final
onCollapse → void Function()?
final
onCopy → void Function()?
final
onCut → void Function()?
final
onDecrease → void Function()?
final
onDidGainAccessibilityFocus → void Function()?
final
onDidLoseAccessibilityFocus → void Function()?
final
onDismiss → void Function()?
final
onExpand → void Function()?
final
onFocus → void Function()?
final
onIncrease → void Function()?
final
onLongPress → void Function()?
final
onLongPressHint → String?
final
onMoveCursorBackwardByCharacter → void Function(bool)?
final
onMoveCursorForwardByCharacter → void Function(bool)?
final
onPaste → void Function()?
final
onScrollDown → void Function()?
final
onScrollLeft → void Function()?
final
onScrollRight → void Function()?
final
onScrollUp → void Function()?
final
onSetSelection → void Function(TextSelection)?
final
onSetText → void Function(String)?
final
onTap → void Function()?
final
onTapHint → String?
final
readOnly → bool?
final
role → SemanticsRole?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopesRoute → bool?
final
selected → bool?
final
slider → bool?
final
sortKey → dynamic
final
tagForChildren → SemanticsTag?
final
textDirection → TextDirection?
final
textField → bool?
final
toggled → bool?
final
tooltip → String?
final
validationResult → SemanticsValidationResult
final
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Abstract function that concrete classes must implement. This must encode the internal data model to a JSON compatible representation.
override
toString() → String
Returns the string encoded JSON representation for this class. This will remove all null values and empty collections from the returned string.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonSemanticsBuilderModel
maybeFromDynamic(dynamic map, {Map<String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonSemanticsBuilderModel?